@@ -25,7 +25,7 @@
 DCORE_USE_NAMESPACE
 
 namespace dss {
-namespace module {
+namespace module_v2 {
 
 LoginModule::LoginModule(QObject *parent)
     : QObject(parent)
@@ -34,7 +34,7 @@ LoginModule::LoginModule(QObject *parent)
     , m_messageCallback(nullptr)
     , m_loginWidget(nullptr)
     , m_appType(AppType::Login)
-    , m_loadPluginType(NotLoad)
+    , m_loadPluginType(Notload)
     , m_isAcceptFingerprintSignal(false)
     , m_waitAcceptSignalTimer(nullptr)
     , m_dconfig(nullptr)
@@ -45,6 +45,7 @@ LoginModule::LoginModule(QObject *parent)
     , m_isLocked(false)
     , m_login1SessionSelf(nullptr)
     , m_IdentifyWithMultipleUserStarted(false)
+    , m_loginAuthenticated(false)
 {
     setObjectName(QStringLiteral("LoginModule"));
 
@@ -55,7 +56,7 @@ LoginModule::LoginModule(QObject *parent)
     //华为机型,从override配置中获取是否加载插件
     if (m_dconfig) {
         bool showPlugin = m_dconfig->value("enableOneKeylogin", false).toBool();
-        m_loadPluginType = showPlugin ? Load : NotLoad;
+        m_loadPluginType = showPlugin ? Load : Notload;
         if (!showPlugin)
             return;
     }
@@ -76,13 +77,16 @@ LoginModule::LoginModule(QObject *parent)
             }
             watcher->deleteLater();
         });
+    } else {
+        qDebug() << Q_FUNC_INFO << " login1Inter is not Valid";
     }
 
     initConnect();
-    startCallHuaweiFingerprint();
 
-    //在2.5秒内没接收到一键登录信号，视为失败
+    // 超时没接收到一键登录信号，视为失败
     m_waitAcceptSignalTimer = new QTimer(this);
+    // 为配合华为指纹规避bug 182893，将时间改为1500毫秒，慎重修改
+    m_waitAcceptSignalTimer->setInterval(1500);
     connect(m_waitAcceptSignalTimer, &QTimer::timeout, this, [this] {
         qInfo() << Q_FUNC_INFO << "start 2.5s, m_isAcceptFingerprintSignal" << m_isAcceptFingerprintSignal;
         QDBusMessage m = QDBusMessage::createMethodCall("com.deepin.daemon.Authenticate", "/com/deepin/daemon/Authenticate/Fingerprint",
@@ -91,6 +95,7 @@ LoginModule::LoginModule(QObject *parent)
         // 将消息发送到Dbus
         QDBusConnection::systemBus().call(m);
         m_waitAcceptSignalTimer->stop();
+        m_loginAuthenticated = true;
         m_IdentifyWithMultipleUserStarted = false;
         if (!m_isAcceptFingerprintSignal) {
             // 防止刚切换指纹认证stop还没结束。
@@ -99,12 +104,13 @@ LoginModule::LoginModule(QObject *parent)
             });
         }
     }, Qt::DirectConnection);
-    m_waitAcceptSignalTimer->setInterval(800);
-    m_waitAcceptSignalTimer->start();
+
+    startCallHuaweiFingerprint();
 }
 
 LoginModule::~LoginModule()
 {
+    qDebug() << Q_FUNC_INFO << "release start ";
     if (m_loginWidget) {
         delete m_loginWidget;
     }
@@ -162,6 +168,8 @@ void LoginModule::startCallHuaweiFingerprint()
         }
         watcher->deleteLater();
     });
+
+    m_waitAcceptSignalTimer->start();
 }
 
 void LoginModule::init()
@@ -198,7 +206,6 @@ void LoginModule::initUI()
     m_spinner->setFixedSize(40, 40);
     m_loginWidget->layout()->addWidget(m_spinner);
     m_spinner->start();
-
 }
 
 void LoginModule::updateInfo()
@@ -252,7 +259,7 @@ void LoginModule::setAppData(AppDataPtr appData)
     m_appData = appData;
 }
 
-void LoginModule::setAuthCallback(AuthCallbackFunc authCallback)
+void LoginModule::setAuthCallback(AuthCallbackFun authCallback)
 {
     m_authCallback = authCallback;
 }
@@ -319,12 +326,22 @@ QString LoginModule::message(const QString &message)
         QJsonArray data = msgObj.value("Data").toArray();
         for (const QJsonValue &limitsInfoStr : data) {
             const QJsonObject limitsInfoObj = limitsInfoStr.toObject();
-            if (limitsInfoObj["flag"].toInt() == AT_Password)
+            if (limitsInfoObj["flag"].toInt() == AuthType::AT_Password)
                 m_isLocked = limitsInfoObj["locked"].toBool();
         }
     } else if (cmdType == "IsPluginEnabled") {
         QJsonObject retDataObj;
-        retDataObj["IsPluginEnabled"] = m_appType != AppType::Lock || m_acceptSleepSignal;
+
+        // 满足以下条件启用插件：
+        // 1. 在登录界面时，一键登录仅在启动或待机休眠唤醒的时候认证一下。
+        // 2. 在锁屏界面，休眠或待机唤醒后。
+        // 3. 上次A账户验证通过(登录时根据验证结果去跳转对应的用户)
+        const bool enable = (m_appType == AppType::Login && !m_loginAuthenticated) || (m_appType == AppType::Lock && m_acceptSleepSignal) || (m_appType == AppType::Login && m_lastAuthResult.result == AuthResult::Success);
+        qInfo() << "Enable plugin: " << enable
+                << ", authenticated: " << m_loginAuthenticated
+                << ", accepted sleep signal: " << m_acceptSleepSignal;
+
+        retDataObj["IsPluginEnabled"] = enable;
         retObj["Data"] = retDataObj;
     }
 
@@ -382,10 +399,12 @@ void LoginModule::slotIdentifyStatus(const QString &name, const int errorCode, c
 void LoginModule::sendAuthData(AuthCallbackData& data)
 {
     if (!m_authCallback) {
-        qDebug() << Q_FUNC_INFO << "m_callbackFun is null";
+        qWarning() << Q_FUNC_INFO << "m_callbackFun is null";
         return;
     }
 
+    m_loginAuthenticated = true;
+
     if (m_spinner) {
         m_spinner->stop();
     }
@@ -399,6 +418,27 @@ void LoginModule::slotPrepareForSleep(bool active)
 
     m_acceptSleepSignal = true;
     if (m_login1SessionSelf == nullptr) {
+        qWarning()  << "m_login1SessionSelf is null";
+        QDBusInterface login1Inter("org.freedesktop.login1", "/org/freedesktop/login1",
+                                   "org.freedesktop.login1.Manager",
+                                   QDBusConnection::systemBus());
+        if(login1Inter.isValid()){
+            QDBusPendingReply<QDBusObjectPath> reply = login1Inter.call("GetSessionByPID" , uint(0));
+            if(!reply.isError()){
+                QString session_self = reply.value().path();
+                qDebug() << "session_self path" << session_self;
+                m_login1SessionSelf = new QDBusInterface("org.freedesktop.login1", session_self, "org.freedesktop.login1.Session", QDBusConnection::systemBus());
+                qDebug() << " m_login1SessionSelf ----" << m_login1SessionSelf;
+            } else {
+                qDebug() << reply.error().message();
+            }
+
+        } else {
+            qDebug() << Q_FUNC_INFO << " login1Inter is not Valid";
+        }
+    }
+
+    if (m_login1SessionSelf == nullptr ) {
         qWarning()  << "m_login1SessionSelf is null";
         return;
     }
@@ -421,18 +461,17 @@ void LoginModule::slotPrepareForSleep(bool active)
 
     if (isSessionAvtive) {
         m_isAcceptFingerprintSignal = false;
+        m_loginAuthenticated = false;
         sendAuthTypeToSession(AuthType::AT_Custom);
         // 等待切换到插件认证完成后再发起多用户认证
         QTimer::singleShot(300, this, [this] {
             startCallHuaweiFingerprint();
-            m_waitAcceptSignalTimer->setInterval(800);
-            m_waitAcceptSignalTimer->start();
         });
         if (m_spinner)
             m_spinner->start();
     } else {
         //fix: 多用户时，第一个用户直接锁屏，然后待机唤醒，在直接切换到另一个用户时，m_login1SessionSelf没有激活，见159949
-        sendAuthTypeToSession(AT_Fingerprint);
+        sendAuthTypeToSession(AuthType::AT_Fingerprint);
     }
 }
 
@@ -443,6 +482,13 @@ void LoginModule::sendAuthTypeToSession(AuthType type)
         m_needSendAuthType = true;
         return;
     }
+
+    // 登录界面密码锁定后只允许切换到密码认证，等待密码锁定解除后才能切换到其它认证类型
+    if (m_isLocked && m_appType == AppType::Login) {
+        qInfo() << "Password is locked and current application is greeter, change authentication type to password";
+        type = AuthType::AT_Password;
+    }
+
     // 这里主要为了防止 在发送切换信号的时候,lightdm还为开启认证，导致切换类型失败
     if (m_authStatus == AuthStatus::None && !m_isLocked && type != AuthType::AT_Custom && m_appType != AppType::Lock) {
         m_needSendAuthType = true;
