@@ -22,9 +22,7 @@
 #include <QSettings>
 
 #include <X11/Xcursor/Xcursor.h>
-#include <X11/Xlib-xcb.h>
 #include <X11/Xlib.h>
-#include <X11/cursorfont.h>
 #include <X11/extensions/Xfixes.h>
 #include <X11/extensions/Xrandr.h>
 #include <cstdlib>
@@ -334,8 +332,7 @@ int main(int argc, char* argv[])
 
     DLogManager::registerConsoleAppender();
 
-    dss::module::ModulesLoader *modulesLoader = &dss::module::ModulesLoader::instance();
-    modulesLoader->start(QThread::LowestPriority);
+    ModulesLoader::instance().start(QThread::LowestPriority);
 
     const QString serviceName = "com.deepin.daemon.Accounts";
     QDBusConnectionInterface *interface = QDBusConnection::systemBus().interface();
@@ -381,6 +378,7 @@ int main(int argc, char* argv[])
 
     auto createFrame = [&](QPointer<QScreen> screen, int count) -> QWidget * {
         LoginWindow *loginFrame = new LoginWindow(model);
+        loginFrame->setGreeter();
         // 创建Frame可能会花费数百毫秒，这个和机器性能有关，在此过程完成后，screen可能已经析构了
         // 在wayland的环境插拔屏幕或者显卡驱动有问题时可能会出现此类问题
         if (screen.isNull()) {
@@ -399,7 +397,11 @@ int main(int argc, char* argv[])
         QObject::connect(loginFrame, &LoginWindow::requestEndAuthentication, worker, &GreeterWorker::endAuthentication);
         QObject::connect(loginFrame, &LoginWindow::authFinished, worker, &GreeterWorker::onAuthFinished);
         QObject::connect(worker, &GreeterWorker::requestUpdateBackground, loginFrame, &LoginWindow::updateBackground);
-        loginFrame->setVisible(model->visible());
+        if (!IsWayland) {
+            loginFrame->setVisible(model->visible());
+        } else {
+            QObject::connect(worker, &GreeterWorker::showLoginWindow, loginFrame, &LoginWindow::setVisible);
+        }
         return loginFrame;
     };
 
@@ -414,7 +416,9 @@ int main(int argc, char* argv[])
     checker.setOutputFormat(DAccessibilityChecker::FullFormat);
     checker.start();
 #endif
-    model->setVisible(true);
+    if (!IsWayland) {
+        model->setVisible(true);
+    }
 
     return a.exec();
 }
