@@ -11,14 +11,9 @@
 
 #include <DSysInfo>
 
-#include <QApplication>
-#include <QDebug>
 #include <QProcess>
-#include <QRegularExpression>
 
-#include <grp.h>
 #include <libintl.h>
-#include <pwd.h>
 #include <unistd.h>
 
 #define DOMAIN_BASE_UID 10000
@@ -50,19 +45,16 @@ LockWorker::LockWorker(SessionBaseModel *const model, QObject *parent)
 
     m_resetSessionTimer->setInterval(15000);
 
-    if (QGSettings::isSchemaInstalled("com.deepin.dde.session-shell")) {
-        m_gsettings = new QGSettings("com.deepin.dde.session-shell", "/com/deepin/dde/session-shell/", this);
-        if(m_gsettings->keys().contains("authResetTime")){
-            int resetTime = m_gsettings->get("auth-reset-time").toInt();
-            if(resetTime > 0)
-               m_resetSessionTimer->setInterval(resetTime);
-        }
+    if (m_gsettings != nullptr && m_gsettings->keys().contains("authResetTime")){
+        int resetTime = m_gsettings->get("auth-reset-time").toInt();
+        if(resetTime > 0)
+           m_resetSessionTimer->setInterval(resetTime);
     }
 
     m_resetSessionTimer->setSingleShot(true);
     connect(m_resetSessionTimer, &QTimer::timeout, this, [=] {
         endAuthentication(m_account, AT_All);
-        destoryAuthentication(m_account);
+        destroyAuthentication(m_account);
         createAuthentication(m_account);
     });
 }
@@ -122,7 +114,7 @@ void LockWorker::initConnections()
             createAuthentication(m_model->currentUser()->name());
         } else {
             endAuthentication(m_account, AT_All);
-            destoryAuthentication(m_account);
+            destroyAuthentication(m_account);
         }
     });
     /* org.freedesktop.login1.Manager */
@@ -130,7 +122,7 @@ void LockWorker::initConnections()
         qInfo() << "DBusLogin1Manager::PrepareForSleep:" << isSleep;
         if (isSleep) {
             endAuthentication(m_account, AT_All);
-            destoryAuthentication(m_account);
+            destroyAuthentication(m_account);
         } else {
             bool wakeUpLock = true;
             // 如果待机唤醒后需要密码则创建验证
@@ -162,7 +154,7 @@ void LockWorker::initConnections()
         } else {
             m_resetSessionTimer->stop();
             endAuthentication(m_account, AT_All);
-            destoryAuthentication(m_model->currentUser()->name());
+            destroyAuthentication(m_model->currentUser()->name());
             setCurrentUser(m_model->currentUser());
             setLocked(false);
         }
@@ -204,7 +196,7 @@ void LockWorker::initData()
 
     /* com.deepin.udcp.iam */
     QDBusInterface ifc("com.deepin.udcp.iam", "/com/deepin/udcp/iam", "com.deepin.udcp.iam", QDBusConnection::systemBus(), this);
-    const bool allowShowCustomUser = valueByQSettings<bool>("", "loginPromptInput", false) || ifc.property("Enable").toBool();
+    const bool allowShowCustomUser = valueByQSettings<bool>("", "loginPromptInput", false) || ifc.property("Enable").toBool() || checkIsADDomain();
     m_model->setAllowShowCustomUser(allowShowCustomUser);
 
     /* init server user or custom user */
@@ -266,13 +258,13 @@ void LockWorker::onAuthStateChanged(const int type, const int state, const QStri
             switch (state) {
             case AS_Success:
                 m_model->updateAuthState(type, state, message);
-                destoryAuthentication(m_account);
+                destroyAuthentication(m_account);
                 onUnlockFinished(true);
                 m_resetSessionTimer->stop();
                 break;
             case AS_Cancel:
                 m_model->updateAuthState(type, state, message);
-                destoryAuthentication(m_account);
+                destroyAuthentication(m_account);
                 break;
             default:
                 break;
@@ -357,7 +349,7 @@ void LockWorker::onAuthStateChanged(const int type, const int state, const QStri
             }
             break;
         case AS_Cancel:
-            destoryAuthentication(m_account);
+            destroyAuthentication(m_account);
             break;
         default:
             break;
@@ -399,11 +391,13 @@ void LockWorker::doPowerAction(const SessionBaseModel::PowerAction action)
         if (delayTime < 0) {
             delayTime = 500;
         }
-        QTimer::singleShot(delayTime, this, [=] {
-            // 待机休眠前设置Locked为true,避免刚唤醒时locked状态不对
-            setLocked(true);
-            m_sessionManagerInter->RequestHibernate();
-        });
+        if (m_powerManagerInter->CanHibernate()){
+            QTimer::singleShot(delayTime, this, [=] {
+                // 待机休眠前设置Locked为true,避免刚唤醒时locked状态不对
+                setLocked(true);
+                m_sessionManagerInter->RequestHibernate();
+            });
+        }
     }
         break;
     case SessionBaseModel::PowerAction::RequireRestart:
@@ -535,7 +529,7 @@ void LockWorker::createAuthentication(const QString &account)
     // 如果验证会话已经存在，销毁后重新开启验证
     if (m_authFramework->authSessionExist(account)) {
         endAuthentication(account, AT_All);
-        destoryAuthentication(account);
+        destroyAuthentication(account);
     }
 
     // 同步密码过期的信息
@@ -563,9 +557,9 @@ void LockWorker::createAuthentication(const QString &account)
  *
  * @param account
  */
-void LockWorker::destoryAuthentication(const QString &account)
+void LockWorker::destroyAuthentication(const QString &account)
 {
-    qInfo() << "LockWorker::destoryAuthentication:" << account;
+    qInfo() << "LockWorker::destroyAuthentication:" << account;
     switch (m_model->getAuthProperty().FrameworkState) {
     case Available:
         m_authFramework->DestroyAuthController(account);
@@ -638,7 +632,7 @@ void LockWorker::onEndAuthentication(const QString &account, const int authType)
 {
     endAuthentication(account, authType);
     if (AT_All == authType) {
-        destoryAuthentication(account);
+        destroyAuthentication(account);
     }
 }
 
