@@ -9,24 +9,13 @@
 #include <DConfig>
 
 #include <QDBusConnection>
-#include <QDBusMessage>
-#include <QDBusReply>
 #include <QDateTime>
 #include <QDebug>
-#include <QDir>
 #include <QFile>
 #include <QGSettings>
-#include <QProcess>
-#include <QStandardPaths>
 #include <QTranslator>
 #include <QJsonDocument>
 
-#include <execinfo.h>
-#include <signal.h>
-#include <stdio.h>
-#include <sys/stat.h>
-#include <time.h>
-
 using namespace std;
 
 DCORE_USE_NAMESPACE
@@ -205,3 +194,22 @@ QString toJson(const QJsonObject &jsonObj)
     doc.setObject(jsonObj);
     return doc.toJson();
 }
+
+bool checkVersion(const QString &target, const QString &base)
+{
+    if (target == base) {
+        return true;
+    }
+    const QStringList baseVersion = base.split(".");
+    const QStringList targetVersion = target.split(".");
+
+    const int baseVersionSize = baseVersion.size();
+    const int targetVersionSize = targetVersion.size();
+    const int size = baseVersionSize < targetVersionSize ? baseVersionSize : targetVersionSize;
+
+    for (int i = 0; i < size; i++) {
+        if (targetVersion[i] == baseVersion[i]) continue;
+        return targetVersion[i].toInt() > baseVersion[i].toInt() ? true : false;
+    }
+    return true;
+}
