@@ -55,6 +55,12 @@ GreeterWorker::GreeterWorker(SessionBaseModel *const model, QObject *parent)
 #ifdef USE_DEEPIN_WAYLAND
     if (!DGuiApplicationHelper::isXWindowPlatform()) {
         m_greeterDisplayWayland = new GreeterDisplayWayland();
+        connect(m_greeterDisplayWayland, &GreeterDisplayWayland::setOutputFinished, this, [this] {
+            QTimer::singleShot(100, this, [this] { // 延时等待显示数据设置完成
+                Q_EMIT showLoginWindow(true);
+                m_model->setVisible(true);
+            });
+        });
         m_greeterDisplayWayland->start();
     }
 #endif
@@ -70,13 +76,10 @@ GreeterWorker::GreeterWorker(SessionBaseModel *const model, QObject *parent)
 
     //认证超时重启
     m_resetSessionTimer->setInterval(15000);
-    if (QGSettings::isSchemaInstalled("com.deepin.dde.session-shell")) {
-        QGSettings gsetting("com.deepin.dde.session-shell", "/com/deepin/dde/session-shell/", this);
-        if (gsetting.keys().contains("authResetTime")) {
-            int resetTime = gsetting.get("auth-reset-time").toInt();
-            if (resetTime > 0)
-                m_resetSessionTimer->setInterval(resetTime);
-        }
+    if (m_gsettings != nullptr && m_gsettings->keys().contains("authResetTime")) {
+        int resetTime = m_gsettings->get("auth-reset-time").toInt();
+        if (resetTime > 0)
+            m_resetSessionTimer->setInterval(resetTime);
     }
 
     m_resetSessionTimer->setSingleShot(true);
@@ -262,7 +265,7 @@ void GreeterWorker::initData()
 
     /* com.deepin.udcp.iam */
     QDBusInterface ifc("com.deepin.udcp.iam", "/com/deepin/udcp/iam", "com.deepin.udcp.iam", QDBusConnection::systemBus(), this);
-    const bool allowShowCustomUser = valueByQSettings<bool>("", "loginPromptInput", false) || ifc.property("Enable").toBool();
+    const bool allowShowCustomUser = valueByQSettings<bool>("", "loginPromptInput", false) || ifc.property("Enable").toBool() || checkIsADDomain();
     m_model->setAllowShowCustomUser(allowShowCustomUser);
 
     /* init current user */
@@ -417,6 +420,13 @@ void GreeterWorker::createAuthentication(const QString &account)
         return;
     }
 
+    // 如果验证会话已经存在，销毁后重新开启验证
+    // TODO 这个处理办法稳健但是比较粗暴，后面需要结合DA梳理一下认证session创建、销毁和复用的时机，优化流程
+    if (m_authFramework->authSessionExist(account)) {
+        endAuthentication(account, AT_All);
+        destoryAuthentication(account);
+    }
+
     m_retryAuth = false;
     std::shared_ptr<User> user_ptr = m_model->findUserByName(account);
     if (user_ptr) {
@@ -732,6 +742,7 @@ void GreeterWorker::onAuthFinished()
     qInfo() << "GreeterWorker::onAuthFinished";
     if (m_greeter->inAuthentication()) {
         m_greeter->respond(m_authFramework->AuthSessionPath(m_account) + QString(";") + m_password);
+        m_model->currentUser()->updatePasswordExpiredInfo();
         if (m_model->currentUser()->expiredState() == User::ExpiredAlready) {
             changePasswd();
         }
@@ -928,7 +939,6 @@ void GreeterWorker::restartResetSessionTimer()
 
 void GreeterWorker::startGreeterAuth(const QString &account)
 {
-
     qInfo() << Q_FUNC_INFO << account ;
     m_greeter->authenticate(account);
 }
