@@ -10,6 +10,7 @@
 #include <DHiDPIHelper>
 #include <DLabel>
 #include <DPaletteHelper>
+#include <DDialogCloseButton>
 
 #include <QKeyEvent>
 #include <QTimer>
@@ -23,14 +24,8 @@
 #include <QValidator>
 #include <QRegExp>
 
-#include <unistd.h>
-
 #include <com_deepin_daemon_accounts_user.h>
 
-#define Service "com.deepin.dialogs.ResetPassword"
-#define Path "/com/deepin/dialogs/ResetPassword"
-#define Interface "com.deepin.dialogs.ResetPassword"
-
 using namespace AuthCommon;
 
 AuthPassword::AuthPassword(QWidget *parent)
@@ -42,6 +37,7 @@ AuthPassword::AuthPassword(QWidget *parent)
     , m_resetPasswordFloatingMessage(nullptr)
     , m_bindCheckTimer(nullptr)
     , m_passwordHintWidget(nullptr)
+    , m_iconButton(nullptr)
 {
     setObjectName(QStringLiteral("AuthPassword"));
     setAccessibleName(QStringLiteral("AuthPassword"));
@@ -99,6 +95,7 @@ void AuthPassword::initUI()
     passwordLayout->addWidget(m_passwordHintBtn, 0, Qt::AlignRight | Qt::AlignVCenter);
 
     mainLayout->addWidget(m_lineEdit);
+    updatePasswordTextMargins();
 }
 
 /**
@@ -114,6 +111,7 @@ void AuthPassword::initConnections()
         if (!focus)
             m_lineEdit->setAlert(false);
         m_authStateLabel->setVisible(!focus && m_showAuthState);
+        updatePasswordTextMargins();
         emit focusChanged(focus);
         if (focus) {
             emit lineEditTextChanged(m_lineEdit->text());
@@ -273,6 +271,7 @@ void AuthPassword::setAnimationState(const bool start)
 void AuthPassword::setCapsLockVisible(const bool on)
 {
     m_capsLock->setVisible(on);
+    updatePasswordTextMargins();
 }
 
 /**
@@ -290,6 +289,7 @@ void AuthPassword::setLimitsInfo(const LimitsInfo &info)
         updateUnlockPrompt();
 
     m_passwordHintBtn->setVisible(info.numFailures > 0 && !m_passwordHint.isEmpty());
+    updatePasswordTextMargins();
     if (m_limitsInfo->locked) {
         setAuthState(AS_Locked, "Locked");
         if (this->isVisible() && isShowResetPasswordMessage()) {
@@ -422,6 +422,7 @@ void AuthPassword::showPasswordHint()
 void AuthPassword::setPasswordHintBtnVisible(const bool isVisible)
 {
     m_passwordHintBtn->setVisible(isVisible);
+    updatePasswordTextMargins();
 }
 
 /**
@@ -469,7 +470,19 @@ void AuthPassword::showResetPasswordMessage()
     pa.setColor(QPalette::HighlightedText, Qt::black);
     m_resetPasswordFloatingMessage = new DFloatingMessage(DFloatingMessage::MessageType::ResidentType);
     m_resetPasswordFloatingMessage->setPalette(pa);
-    m_resetPasswordFloatingMessage->setIcon(QIcon::fromTheme("gtk-dialog-error").pixmap(20, 20));
+    // DFloatingMessage 中未放开seticonsize接口，无法设置图标大小，使用缩放函数会造成图标锯齿
+    // 只能使用findChildren找到对应的图标控件来设置图标大小进行规避
+    // DFloatingMessage中有两个按钮一个是DIconButton,另一个是继承于DIconButton的DDialogCloseButton，需要区分
+    QList<DIconButton *> btnList = m_resetPasswordFloatingMessage->findChildren<DIconButton *>();
+    foreach (const auto iconButton, btnList) {
+        DDialogCloseButton * closeButton = qobject_cast<DDialogCloseButton *>(iconButton);
+        if (closeButton) {
+            continue;
+        }
+        iconButton->installEventFilter(this);
+        m_iconButton = iconButton;
+    }
+    m_resetPasswordFloatingMessage->setIcon(QIcon("://misc/images/dss_warning.svg"));
     DSuggestButton *suggestButton = new DSuggestButton(tr("Reset Password"));
     suggestButton->setAutoDefault(true);
     m_resetPasswordFloatingMessage->setWidget(suggestButton);
@@ -604,6 +617,21 @@ bool AuthPassword::eventFilter(QObject *watched, QEvent *event)
             return true;
         }
     }
+
+    if (watched == m_iconButton && event->type() == QEvent::Paint) {
+        QPainter painter(m_iconButton);
+        painter.setRenderHint(QPainter::Antialiasing, true);
+        painter.setRenderHint(QPainter::SmoothPixmapTransform, true);
+
+        if (!m_iconButton->icon().isNull()) {
+            QRect iconRect(0, 0, 20, 20);
+            iconRect.moveCenter(m_iconButton->rect().center());
+            m_iconButton->icon().paint(&painter, iconRect);
+        }
+
+        return true;
+    }
+
     return false;
 }
 
@@ -620,6 +648,7 @@ void AuthPassword::hideEvent(QHideEvent *event)
 void AuthPassword::showEvent(QShowEvent *event)
 {
     m_passwordHintBtn->setVisible(m_limitsInfo->numFailures > 0 && !m_passwordHint.isEmpty());
+    updatePasswordTextMargins();
     if (m_limitsInfo->locked) {
         setAuthState(AS_Locked, "Locked");
         if (isShowResetPasswordMessage()) {
@@ -639,6 +668,7 @@ void AuthPassword::setAuthStatueVisible(bool visible)
 {
     m_showAuthState = visible;
     m_authStateLabel->setVisible(visible && !hasFocus());
+    updatePasswordTextMargins();
 }
 
 void AuthPassword::showAlertMessage(const QString &text)
@@ -657,3 +687,14 @@ void AuthPassword::hidePasswordHintWidget()
     // 恢复调色板
     DPaletteHelper::instance()->resetPalette(this->topLevelWidget());
 }
+
+
+void AuthPassword::updatePasswordTextMargins()
+{
+    // 根据大小写提示是否显示，设置密码框左边距,根据密码提示和显示密码设置密码杠右边距
+    QMargins textMargins = m_lineEdit->lineEdit()->textMargins();
+    textMargins.setLeft(m_capsLock->isVisible() ? m_capsLock->width() : 0);
+    textMargins.setRight((m_authStateLabel->isVisible() ? m_authStateLabel->width() : 0) +
+                         (m_passwordHintBtn->isVisible() ? m_passwordHintBtn->width() : 0));
+    m_lineEdit->lineEdit()->setTextMargins(textMargins);
+}
