@@ -16,7 +16,6 @@
 #include <DAlertControl>
 
 #define Password_Auth QStringLiteral(":/misc/images/auth/password.svg")
-//const QString Password_Auth = ":/misc/images/auth/password.svg";
 
 class DLineEditEx;
 DWIDGET_USE_NAMESPACE
@@ -69,6 +68,7 @@ private:
     bool isUserAccountBinded();
     void showAlertMessage(const QString &text);
     void hidePasswordHintWidget();
+    void updatePasswordTextMargins();
 
 private:
     DLabel *m_capsLock;             // 大小写状态
@@ -80,6 +80,7 @@ private:
     uid_t m_currentUid; // 当前用户uid
     QTimer *m_bindCheckTimer;
     DAlertControl *m_passwordHintWidget;
+    DIconButton *m_iconButton;
 };
 
 #endif // AUTHPASSWORD_H
