@@ -8,6 +8,7 @@
 #include "dlineeditex.h"
 
 #include <DHiDPIHelper>
+#include <DDialogCloseButton>
 
 #include <QKeyEvent>
 #include <QTimer>
@@ -20,13 +21,8 @@
 #include <QValidator>
 #include <QRegExp>
 
-#include <unistd.h>
 #include <com_deepin_daemon_accounts_user.h>
 
-#define Service "com.deepin.dialogs.ResetPassword"
-#define Path "/com/deepin/dialogs/ResetPassword"
-#define Interface "com.deepin.dialogs.ResetPassword"
-
 using namespace AuthCommon;
 
 AuthSingle::AuthSingle(QWidget *parent)
@@ -38,6 +34,7 @@ AuthSingle::AuthSingle(QWidget *parent)
     , m_resetPasswordMessageVisible(false)
     , m_resetPasswordFloatingMessage(nullptr)
     , m_bindCheckTimer(nullptr)
+    , m_iconButton(nullptr)
 {
     setObjectName(QStringLiteral("AuthSingle"));
     setAccessibleName(QStringLiteral("AuthSingle"));
@@ -95,6 +92,7 @@ void AuthSingle::initUI()
     passwordLayout->addWidget(m_passwordHintBtn, 0, Qt::AlignRight | Qt::AlignVCenter);
 
     mainLayout->addWidget(m_lineEdit);
+    updatePasswordTextMargins();
 }
 
 /**
@@ -232,6 +230,7 @@ void AuthSingle::setAuthState(const int state, const QString &result)
 void AuthSingle::setCapsLockVisible(const bool on)
 {
     m_capsLock->setVisible(on);
+    updatePasswordTextMargins();
 }
 
 /**
@@ -417,6 +416,7 @@ void AuthSingle::showPasswordHint()
 void AuthSingle::setPasswordHintBtnVisible(const bool isVisible)
 {
     m_passwordHintBtn->setVisible(isVisible);
+    updatePasswordTextMargins();
 }
 
 /**
@@ -444,7 +444,19 @@ void AuthSingle::showResetPasswordMessage()
     pa.setColor(QPalette::HighlightedText, Qt::black);
     m_resetPasswordFloatingMessage = new DFloatingMessage(DFloatingMessage::MessageType::ResidentType);
     m_resetPasswordFloatingMessage->setPalette(pa);
-    m_resetPasswordFloatingMessage->setIcon(QIcon::fromTheme("gtk-dialog-error").pixmap(20, 20));
+    // DFloatingMessage 中未放开seticonsize接口，无法设置图标大小，使用缩放会造成图标锯齿
+    // 只能使用findChildren找到对应的图标控件来设置图标大小进行规避
+    // DFloatingMessage中有两个按钮一个是DIconButton,另一个是继承于DIconButton的DDialogCloseButton，需要区分
+    QList<DIconButton *> btnList = m_resetPasswordFloatingMessage->findChildren<DIconButton *>();
+    foreach (const auto iconButton, btnList) {
+        DDialogCloseButton * closeButton = qobject_cast<DDialogCloseButton *>(iconButton);
+        if (closeButton) {
+            continue;
+        }
+        iconButton->installEventFilter(this);
+        m_iconButton = iconButton;
+    }
+    m_resetPasswordFloatingMessage->setIcon(QIcon("://misc/images/dss_warning.svg"));
     DSuggestButton *suggestButton = new DSuggestButton(tr("Reset Password"));
     suggestButton->setAutoDefault(true);
     m_resetPasswordFloatingMessage->setWidget(suggestButton);
@@ -549,6 +561,15 @@ bool AuthSingle::isUserAccountBinded()
     }
 }
 
+void AuthSingle::updatePasswordTextMargins()
+{
+    // 根据大小写提示是否显示，设置密码框左边距,根据密码提示和显示密码设置密码杠右边距
+    QMargins textMargins = m_lineEdit->lineEdit()->textMargins();
+    textMargins.setLeft(m_capsLock->isVisible() ? m_capsLock->width() : 0);
+    textMargins.setRight(m_passwordHintBtn->isVisible() ? m_passwordHintBtn->width() : 0);
+    m_lineEdit->lineEdit()->setTextMargins(textMargins);
+}
+
 /**
  * @brief 更新重置密码UI相关状态
  */
@@ -580,5 +601,19 @@ bool AuthSingle::eventFilter(QObject *watched, QEvent *event)
         closeResetPasswordMessage();
     }
 
+    if (watched == m_iconButton && event->type() == QEvent::Paint) {
+        QPainter painter(m_iconButton);
+        painter.setRenderHint(QPainter::Antialiasing, true);
+        painter.setRenderHint(QPainter::SmoothPixmapTransform, true);
+
+        if (!m_iconButton->icon().isNull()) {
+            QRect iconRect(0, 0, 20, 20);
+            iconRect.moveCenter(m_iconButton->rect().center());
+            m_iconButton->icon().paint(&painter, iconRect);
+        }
+
+        return true;
+    }
+
     return false;
 }
