@@ -37,7 +37,6 @@ AuthWidget::AuthWidget(QWidget *parent)
     , m_accountEdit(nullptr)
     , m_userNameWidget(nullptr)
     , m_capslockMonitor(nullptr)
-    , m_keyboardTypeClip(nullptr)
     , m_singleAuth(nullptr)
     , m_passwordAuth(nullptr)
     , m_fingerprintAuth(nullptr)
@@ -45,6 +44,7 @@ AuthWidget::AuthWidget(QWidget *parent)
     , m_faceAuth(nullptr)
     , m_irisAuth(nullptr)
     , m_customAuth(nullptr)
+    , m_refreshTimer(new QTimer(this))
 {
     setObjectName(QStringLiteral("AuthWidget"));
     setAccessibleName(QStringLiteral("AuthWidget"));
@@ -55,6 +55,15 @@ AuthWidget::AuthWidget(QWidget *parent)
     m_capslockMonitor = KeyboardMonitor::instance();
     m_capslockMonitor->start(QThread::LowestPriority);
     m_frameDataBind = FrameDataBind::Instance();
+
+    m_refreshTimer->setInterval(1000);
+    m_refreshTimer->start();
+    connect(m_refreshTimer, &QTimer::timeout, this, [ this ] {
+        if(QTime::currentTime().minute() == 0 && QTime::currentTime().second() == 0){
+            m_user->updatePasswordExpiredInfo();
+            updatePasswordExpiredState();
+        }
+    });
 }
 
 AuthWidget::~AuthWidget()
@@ -78,7 +87,7 @@ void AuthWidget::initUI()
     m_accountEdit->setClearButtonEnabled(false);
     m_accountEdit->setPlaceholderText(tr("Account"));
     // 用户名
-    m_userNameWidget = new UserNameWidget(true, this);
+    m_userNameWidget = new UserNameWidget(false, true, this);
     /* 密码过期提示 */
     m_expiredStateLabel->setAccessibleName("ExpiredStateLabel");
     m_expiredStateLabel->setWordWrap(true);
