@@ -6,11 +6,8 @@
 #include "sessionbasemodel.h"
 #include "userinfo.h"
 
-#include <grp.h>
-#include <libintl.h>
-#include <pwd.h>
-#include <unistd.h>
 #include <QProcessEnvironment>
+#include <QFile>
 
 #define POWER_CAN_SLEEP "POWER_CAN_SLEEP"
 #define POWER_CAN_HIBERNATE "POWER_CAN_HIBERNATE"
@@ -24,12 +21,16 @@ AuthInterface::AuthInterface(SessionBaseModel *const model, QObject *parent)
     , m_loginedInter(new LoginedInter("com.deepin.daemon.Accounts", "/com/deepin/daemon/Logined", QDBusConnection::systemBus(), this))
     , m_login1Inter(new DBusLogin1Manager("org.freedesktop.login1", "/org/freedesktop/login1", QDBusConnection::systemBus(), this))
     , m_powerManagerInter(new PowerManagerInter("com.deepin.daemon.PowerManager", "/com/deepin/daemon/PowerManager", QDBusConnection::systemBus(), this))
-    , m_authenticateInter(new Authenticate("com.deepin.daemon.Authenticate", "/com/deepin/daemon/Authenticate", QDBusConnection::systemBus(), this))
     , m_dbusInter(new DBusObjectInter("org.freedesktop.DBus", "/org/freedesktop/DBus", QDBusConnection::systemBus(), this))
     , m_lastLogoutUid(0)
     , m_currentUserUid(0)
     , m_loginUserList(0)
 {
+    // 需要先初始化m_gsettings
+    if (QGSettings::isSchemaInstalled("com.deepin.dde.session-shell")) {
+        m_gsettings = new QGSettings("com.deepin.dde.session-shell", "/com/deepin/dde/session-shell/", this);
+    }
+
     if (m_login1Inter->isValid()) {
        QString session_self = m_login1Inter->GetSessionByPID(0).value().path();
        m_login1SessionSelf = new Login1SessionSelf("org.freedesktop.login1", session_self, QDBusConnection::systemBus(), this);
@@ -235,3 +236,9 @@ void AuthInterface::checkPowerInfo()
 
     m_model->setHasSwap(can_hibernate);
 }
+
+bool AuthInterface::checkIsADDomain()
+{
+    //只有加入AD域后，才会生成此文件
+    return QFile::exists("/etc/krb5.keytab");
+}
