@@ -24,7 +24,6 @@ class MFAWidget;
 class SFAWidget;
 class UserFrameList;
 class ControlWidget;
-class UserInputWidget;
 class User;
 class ShutdownWidget;
 class LogoWidget;
@@ -98,11 +97,9 @@ protected:
     std::shared_ptr<User> m_user;
     QList<QMetaObject::Connection> m_currentUserConnects;
     LogoWidget *m_logoWidget;
-    TimeWidget *m_timeWidget;
     MediaWidget *m_mediaWidget = nullptr;
     com::deepin::wm *m_wmInter;
     QWidget *m_loginWidget;
-    QMap<QString, QWidget *> m_centeralWidgets;
 
     SFAWidget *m_sfaWidget;
     MFAWidget *m_mfaWidget;
