@@ -15,12 +15,11 @@
 #include "dlineeditex.h"
 #include "framedatabind.h"
 #include "keyboardmonitor.h"
-#include "modules_loader.h"
 #include "sessionbasemodel.h"
 #include "useravatar.h"
+#include "plugin_manager.h"
 
 #include <DFontSizeManager>
-#include <DHiDPIHelper>
 
 #include <QSpacerItem>
 
@@ -139,9 +138,9 @@ void SFAWidget::setAuthType(const int type)
         qInfo() << "Sfa is inited: " << m_inited << ", sfa widgets size: " << SFAWidgetObjs.size();
         if (m_inited || SFAWidgetObjs.size() <= 1) {
             qInfo() << Q_FUNC_INFO << "m_customAuth->authType()" << m_customAuth->authType();
-            if (m_customAuth->pluginConfig().defaultAuthLevel == AuthCommon::DefaultAuthLevel::Default) {
+            if (m_customAuth->pluginConfig().defaultAuthLevel == LoginPlugin::DefaultAuthLevel::Default) {
                 m_currentAuthType = m_currentAuthType == AT_All ? AT_Custom : m_currentAuthType;
-            } else if (m_customAuth->pluginConfig().defaultAuthLevel == AuthCommon::DefaultAuthLevel::StrongDefault) {
+            } else if (m_customAuth->pluginConfig().defaultAuthLevel == LoginPlugin::DefaultAuthLevel::StrongDefault) {
                 m_currentAuthType = AT_Custom;
             }
         }
@@ -234,6 +233,7 @@ void SFAWidget::setAuthType(const int type)
         m_frameDataBind->clearValue("SFSingleAuthMsg");
     }
 
+    m_chooseAuthButtonBox->setEnabled(true);
     if (AppType::Login == m_model->appType() && m_passwordAuth) {
         m_chooseAuthButtonBox->setEnabled(!m_passwordAuth->isLocked());
         if (m_passwordAuth->isLocked()) {
@@ -773,8 +773,8 @@ void SFAWidget::initCustomAuth()
 
     m_customAuth = new AuthCustom(this);
 
-    dss::module::LoginModuleInterface *module = dynamic_cast<dss::module::LoginModuleInterface *>(dss::module::ModulesLoader::instance().findModulesByType(0).values().first());
-    m_customAuth->setModule(module);
+    LoginPlugin *plugin = PluginManager::instance()->getLoginPlugin();
+    m_customAuth->setModule(plugin);
     m_customAuth->setModel(m_model);
     m_customAuth->initUi();
     m_customAuth->hide();
@@ -792,8 +792,8 @@ void SFAWidget::initCustomAuth()
     connect(m_customAuth, &AuthCustom::requestCheckAccount, this, [this] (const QString &account) {
         qInfo() << "Request check account: " << account;
         if (m_user && m_user->name() == account) {
-            dss::module::AuthCallbackData data = m_customAuth->getCurrentAuthData();
-            if (data.result == dss::module::Success)
+            LoginPlugin::AuthCallbackData data = m_customAuth->getCurrentAuthData();
+            if (data.result == LoginPlugin::AuthResult::Success)
                 Q_EMIT sendTokenToAuth(m_user->name(), AT_Custom, data.token);
             else
                 qWarning() << Q_FUNC_INFO << "auth failed";
@@ -808,7 +808,7 @@ void SFAWidget::initCustomAuth()
 
     /* 认证选择按钮 */
     DButtonBoxButton *btn = new DButtonBoxButton(DStyle::SP_SelectElement, QString(), this);
-    const QString &iconStr = module->icon();
+    const QString &iconStr = plugin->icon();
     const QIcon icon = QFile::exists(iconStr) ? QIcon(iconStr) : QIcon::fromTheme(iconStr);
     if (!icon.isNull()) {
         btn->setIcon(icon);
@@ -817,7 +817,7 @@ void SFAWidget::initCustomAuth()
     btn->setFixedSize(AuthButtonSize);
     btn->setFocusPolicy(Qt::NoFocus);
     m_authButtons.insert(AT_Custom, btn);
-    connect(btn, &DButtonBoxButton::toggled, this, [this, module](const bool checked) {
+    connect(btn, &DButtonBoxButton::toggled, this, [this](const bool checked) {
         if (checked) {
             qDebug() << Q_FUNC_INFO << "Custom auth is checked";
             m_biometricAuthState->hide();
@@ -976,7 +976,7 @@ int SFAWidget::getTopSpacing() const
             - m_bioBottomSpacingHolder->geometry().height()
             - m_authTypeBottomSpacingHolder->sizeHint().height()
             - ((m_faceAuth || m_fingerprintAuth || m_irisAuth) ? BIO_AUTH_STATE_PLACE_HOLDER_HEIGHT : 0)
-            - (m_authButtons.size() > 1 ? calcCurrentHeight(CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING) : 0);
+            - (showAuthButtonBox() ? calcCurrentHeight(CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING) : 0);
 
     return qMax(15, deltaY);
 }
@@ -994,7 +994,7 @@ void SFAWidget::resizeEvent(QResizeEvent *event)
  */
 void SFAWidget::updateSpaceItem()
 {
-    m_authTypeBottomSpacingHolder->changeSize(0, m_authButtons.size() > 1 ? calcCurrentHeight(CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING) : 0);
+    m_authTypeBottomSpacingHolder->changeSize(0, showAuthButtonBox() ? calcCurrentHeight(CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING) : 0);
 
     if (m_faceAuth || m_fingerprintAuth || m_irisAuth) {
         m_bioBottomSpacingHolder->changeSize(0, calcCurrentHeight(CHOOSE_AUTH_TYPE_BUTTON_BOTTOM_SPACING));
@@ -1028,13 +1028,22 @@ void SFAWidget::updateFocus()
             break;
         }
     }
+
+    // 人脸和虹膜识别同步焦点
+    if (m_currentAuthType == AT_Face || m_currentAuthType == AT_Iris) {
+        if ((m_faceAuth && m_faceAuth->authState() == AS_Success) ||
+            (m_irisAuth && m_irisAuth->authState() == AS_Success)) {
+            m_lockButton->setFocus();
+        }
+    }
 }
 
 void SFAWidget::showEvent(QShowEvent *event)
 {
     AuthWidget::showEvent(event);
 
-    QTimer::singleShot(0, this, &SFAWidget::updateFocus);
+    // 延时处理，x下存在showEvent中设置焦点无效的情况，为页面未显示出来的原因。
+    QTimer::singleShot(100, this, &SFAWidget::updateFocus);
 }
 
 void SFAWidget::updateBlurEffectGeometry()
@@ -1100,14 +1109,19 @@ void SFAWidget::onRequestChangeAuth(const int authType)
             << ", chooseAuthButtonBox is enabled" << m_chooseAuthButtonBox->isEnabled()
             << ", current authentication type" << m_currentAuthType;
 
-    if (!m_chooseAuthButtonBox->isEnabled()) {
-        qWarning() << "Authentication button box is disabled";
+    if (authType != AuthCommon::AT_Password && !m_chooseAuthButtonBox->isEnabled()) {
+        qWarning() << "Authentication button box is disabled and authentication type is not password.";
         return;
     }
 
     if (!m_authButtons.contains(authType)) {
         qWarning() << "Authentication buttons do not contain the type";
-        m_chooseAuthButtonBox->button(m_authButtons.firstKey())->toggled(true);
+        // 登录选项默认显示上一次认证方式，当不存在上一次认证，默认显示第一种认证方式
+        if (m_authButtons.contains(m_user->lastAuthType())) {
+            m_chooseAuthButtonBox->button(m_user->lastAuthType())->toggled(true);
+        } else {
+            m_chooseAuthButtonBox->button(m_authButtons.firstKey())->toggled(true);
+        }
         return ;
     }
 
@@ -1133,23 +1147,21 @@ bool SFAWidget::useCustomAuth() const
     }
 
     // 是否加载了认证插件
-    const QList<dss::module::BaseModuleInterface *> interfaces = dss::module::ModulesLoader::instance().findModulesByType(dss::module::BaseModuleInterface::LoginType).values();
-    if (interfaces.isEmpty()) {
+    LoginPlugin* plugin = PluginManager::instance()->getLoginPlugin();
+    if (!plugin) {
         qInfo() << "There is no login plugin";
         return false;
     }
 
-    dss::module::LoginModuleInterface * const module = dynamic_cast<dss::module::LoginModuleInterface *>(interfaces.first());
-
     // 当前插件是否启动，由插件自己决定
-    if (!AuthCustom::isPluginEnabled(module)) {
+    if (!plugin->isPluginEnabled()) {
         qInfo() << "Plugin is disabled";
         return false;
     }
 
     // 判断认证插件是否支持"..."用户
     if (m_user && m_user->type() == User::Default) {
-        const bool supportDefaultUser = AuthCustom::supportDefaultUser(module);
+        const bool supportDefaultUser = plugin->supportDefaultUser();
         if (!supportDefaultUser) {
             qInfo() << "Do not support default user";
             return false;
@@ -1168,3 +1180,9 @@ void SFAWidget::onActiveAuth(int authType)
 
     emit requestStartAuthentication(m_model->currentUser()->name(), authType);
 }
+
+bool SFAWidget::showAuthButtonBox() const
+{
+    return (m_customAuth && !m_customAuth->pluginConfig().showSwitchButton) ?
+        m_authButtons.count() > 2 : m_authButtons.count() > 1;
+}
