@@ -19,7 +19,6 @@
 #include <QWidget>
 
 class AuthModule;
-class KbLayoutWidget;
 class KeyboardMonitor;
 
 class DLineEditEx;
@@ -73,6 +72,7 @@ private:
     void updateFocus();
     void initAccount();
     bool useCustomAuth() const;
+    bool showAuthButtonBox() const;
 
 private:
     QVBoxLayout *m_mainLayout;
