@@ -18,7 +18,7 @@
 #include <QScroller>
 #include <QVBoxLayout>
 
-const int UserFrameSpaceing = 40;
+const int UserFrameSpacing = 40;
 
 using namespace DDESESSIONCC;
 
@@ -50,6 +50,7 @@ UserFrameList::UserFrameList(QWidget *parent)
     });
 
     DConfigHelper::instance()->bind(this, SHOW_USER_NAME);
+    DConfigHelper::instance()->bind(this, USER_FRAME_MAX_WIDTH);
 }
 
 void UserFrameList::initUI()
@@ -93,7 +94,7 @@ void UserFrameList::setFixedSize(const QSize &size)
 {
     QWidget::setFixedSize(size);
     //先确定界面大小，再根据界面大小计算用户列表区域大小
-    updateLayout();
+    updateLayout(width());
 }
 
 void UserFrameList::handlerBeforeAddUser(std::shared_ptr<User> user)
@@ -131,7 +132,7 @@ void UserFrameList::addUser(const std::shared_ptr<User> user)
     m_flowLayout->insertWidget(index, widget);
 
     //添加用户和删除用户时，重新计算区域大小
-    updateLayout();
+    updateLayout(width());
 }
 
 //删除用户
@@ -151,7 +152,7 @@ void UserFrameList::removeUser(const std::shared_ptr<User> user)
     }
 
     //添加用户和删除用户时，重新计算区域大小
-    updateLayout();
+    updateLayout(width());
 }
 
 //点击用户
@@ -188,7 +189,7 @@ void UserFrameList::switchNextUser()
                 //处理m_scrollArea翻页显示
                 int selectedRight = m_loginWidgets[i]->geometry().right();
                 int scrollRight = m_scrollArea->widget()->geometry().right();
-                if (selectedRight + UserFrameSpaceing == scrollRight) {
+                if (selectedRight + UserFrameSpacing == scrollRight) {
                     QPoint topLeft;
                     if (m_rowCount == 1) {
                         topLeft = m_loginWidgets[i + 1]->geometry().topLeft();
@@ -244,20 +245,38 @@ void UserFrameList::onOtherPageChanged(const QVariant &value)
     }
 }
 
-void UserFrameList::updateLayout()
+void UserFrameList::updateLayout(int width)
 {
     //处理窗体数量小于5个时的居中显示，取 窗体数量*窗体宽度 和 最大宽度 的较小值，设置为m_centerWidget的宽度
     auto userWidget = m_loginWidgets.constFirst();
     int userWidgetHeight = UserFrameHeight;
     if (userWidget)
         userWidgetHeight = userWidget->heightHint();
-    int count = m_flowLayout->count();
-    if (count < 5 && count > 0) {
-        m_scrollArea->setFixedSize((UserFrameWidth + UserFrameSpaceing) * count, userWidgetHeight + 20);
+
+    int resolutionWidth = 0;
+    QWidget* parentWidget = qobject_cast<QWidget*>(this->parent());
+    if (parentWidget)
+        resolutionWidth = parentWidget->width();
+
+    // 根据界面总宽度计算第一行可以显示多少用户信息
+    int countWidth = 0;
+    int count = 0;
+    for (auto w : m_loginWidgets) {
+        countWidth += w->width() + UserFrameSpacing;
+        count += 1;
+        if (count > 5 || countWidth > resolutionWidth - 200 * 2) {
+            countWidth -= w->width() + UserFrameSpacing;
+            count -= 1;
+            break;
+        }
     }
-    if (count >= 5) {
-        m_scrollArea->setFixedSize((UserFrameWidth + UserFrameSpaceing) * 5, (userWidgetHeight + UserFrameSpaceing) * 2);
+
+    if (m_flowLayout->count() <= count) {
+        m_scrollArea->setFixedSize(countWidth, userWidgetHeight + 20);
+    } else {
+        m_scrollArea->setFixedSize(countWidth, (userWidgetHeight + UserFrameSpacing) * 2);
     }
+
     m_centerWidget->setFixedWidth(m_scrollArea->width() - 10);
 
     std::shared_ptr<User> user = m_model->currentUser();
@@ -324,15 +343,16 @@ void UserFrameList::focusOutEvent(QFocusEvent *event)
 
 void UserFrameList::resizeEvent(QResizeEvent *event)
 {
-    updateLayout();
-
     QWidget::resizeEvent(event);
+    updateLayout(width());
 }
 
 void UserFrameList::OnDConfigPropertyChanged(const QString &key, const QVariant &value)
 {
-    if (key == SHOW_USER_NAME) {
+    if (key == SHOW_USER_NAME || key == USER_FRAME_MAX_WIDTH) {
         // 需要等待UserWidget处理完，延时100ms后更新布局
-        QTimer::singleShot(100, this, &UserFrameList::updateLayout);
+        QTimer::singleShot(100, this, [ = ]{
+            updateLayout(width());
+        });
     }
 }
