@@ -28,7 +28,7 @@ public:
     explicit UserFrameList(QWidget *parent = nullptr);
     void setModel(SessionBaseModel *model);
     void setFixedSize(const QSize &size);
-    void updateLayout();
+    void updateLayout(int width);
 
 signals:
     void requestSwitchUser(std::shared_ptr<User> user);
@@ -63,7 +63,6 @@ private:
     SessionBaseModel *m_model;
     FrameDataBind *m_frameDataBind;
     QWidget *m_centerWidget;
-    int m_colCount;
     int m_rowCount;
 };
 
