@@ -17,6 +17,9 @@
 #include <QScreen>
 #include <QTimer>
 #include <QWindow>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QJsonArray>
 
 Q_LOGGING_CATEGORY(DDE_SS, "dss.active")
 
@@ -41,6 +44,11 @@ FullscreenBackground::FullscreenBackground(SessionBaseModel *model, QWidget *par
     , m_fadeOutAniFinished(false)
     , m_enableAnimation(true)
     , m_blackWidget(new BlackWidget(this))
+    , m_sysDisplayInter(new QDBusInterface("com.deepin.system.Display",
+                                       "/com/deepin/system/Display",
+                                       "com.deepin.system.Display",
+                                       QDBusConnection::systemBus()))
+    , m_isGreeter(false)
 {
 #ifndef QT_DEBUG
     if (!m_model->isUseWayland()) {
@@ -89,6 +97,8 @@ void FullscreenBackground::updateBackground(const QString &path)
     if (m_useSolidBackground)
         return;
 
+    qInfo() << Q_FUNC_INFO << " path : " << path;
+
     if (isPicture(path)) {
         // 动画播放完毕不再需要清晰的背景图片
         if (!m_fadeOutAniFinished && !(backgroundPath == path && contains(PIXMAP_TYPE_BACKGROUND))) {
@@ -148,6 +158,11 @@ void FullscreenBackground::setEnterEnable(bool enable)
     m_enableEnterEvent = enable;
 }
 
+void FullscreenBackground::setGreeter()
+{
+    m_isGreeter = true;
+}
+
 void FullscreenBackground::setScreen(QPointer<QScreen> screen, bool isVisible)
 {
     if (screen.isNull())
@@ -278,7 +293,7 @@ void FullscreenBackground::tryActiveWindow(int count/* = 9*/)
 
 void FullscreenBackground::enterEvent(QEvent *event)
 {
-    if (m_enableEnterEvent && m_model->visible()) {
+    if (m_enableEnterEvent && m_model->visible() && !m_content->isVisible()) {
         m_content->show();
         emit contentVisibleChanged(true);
         // 多屏情况下，此Frame晚于其它Frame显示出来时，可能处于未激活状态（特别是在wayland环境下比较明显）
@@ -359,6 +374,10 @@ void FullscreenBackground::showEvent(QShowEvent *event)
         }
 
         Q_EMIT requestDisableGlobalShortcutsForWayland(true);
+    } else {
+        if (m_model->visible() && m_content->isVisible() && !geometry().contains(QCursor::pos())) {
+            m_content->hide();
+        }
     }
 
     updateGeometry();
@@ -370,10 +389,12 @@ void FullscreenBackground::hideEvent(QHideEvent *event)
 {
     if (m_model->isUseWayland()) {
         Q_EMIT requestDisableGlobalShortcutsForWayland(false);
+
+        if (geometry().contains(QCursor::pos())) {
+            m_content->hide();
+        }
     }
 
-    // 将content隐藏起来，下次锁屏拉起的时候显示鼠标所在屏幕，这样可以避免多屏显示认证界面（如果时序有问题的话）和 屏幕闪现认证界面的问题
-    m_content->hide();
     QWidget::hideEvent(event);
 }
 
@@ -420,12 +441,63 @@ void FullscreenBackground::updateGeometry()
     qInfo() << "set background screen:" << m_screen;
 
     if (!m_screen.isNull()) {
-        setGeometry(m_screen->geometry());
+        if (m_isGreeter) {
+            QRect rect = m_screen->geometry();
+            QSize size = getGreeterSize();
+            double ratiof = devicePixelRatioF();
+            if (size != QSize(0, 0) && m_screen->geometry().size() != size) {
+                rect.setSize(size / ratiof);
+                qInfo() << "set user set greeter background geometry:" << rect << ratiof;
+            }
+            setGeometry(rect);
+
+        } else {
+            setGeometry(m_screen->geometry());
+        }
+
         qInfo() << "set background geometry:" << m_screen << m_screen->geometry() << "lockFrame:"
                 << this  << " lockframe geometry:" << this->geometry();
+    } else {
+        qWarning() << Q_FUNC_INFO << "m_isGreeter is nullptr.";
     }
 }
 
+QSize FullscreenBackground::parseJson(QString first, QString second, QString third)
+{
+    if (!m_sysDisplayInter) {
+        return QSize(0, 0);
+    }
+
+    QSize size = QSize(0, 0);
+    QDBusReply<QString> configReply = m_sysDisplayInter->call("GetConfig");
+    if (configReply.isValid()) {
+        QString config = configReply.value();
+        QJsonParseError jsonError;
+        QJsonDocument jsonDoc(QJsonDocument::fromJson(config.toStdString().data(), &jsonError));
+        if (jsonError.error == QJsonParseError::NoError) {
+            QJsonObject greeterMonitor = jsonDoc.object().value(first).toObject().value(second).toObject().value(third).toObject();
+
+            auto enabled = greeterMonitor.value("Enabled").toBool();
+            if (enabled) {
+                size.setWidth(greeterMonitor.value("Width").toInt());
+                size.setHeight(greeterMonitor.value("Height").toInt());
+            }
+
+            qDebug() << Q_FUNC_INFO << enabled << size;
+        }
+    } else {
+        qWarning() << " com.deepin.system.Display.GetConfig reply.isValid : " << configReply.isValid();
+    }
+
+    return QSize(size);
+}
+
+
+QSize FullscreenBackground::getGreeterSize()
+{
+    return parseJson("Config", "Cache", "GreeterMonitor");
+}
+
 /********************************************************
  * 监听主窗体属性。
  * 用户登录界面，主窗体在某时刻会被设置为WindowDeactivate，
@@ -533,6 +605,14 @@ bool FullscreenBackground::contains(int type)
 
 void FullscreenBackground::moveEvent(QMoveEvent *event)
 {
+    // 规避 bug189309，登录时后端屏幕变化通知太晚
+    if (m_content && !m_content->isVisible()) {
+        if (m_model->isUseWayland()) {
+            if (m_model->visible() && geometry().contains(QCursor::pos())) {
+                m_content->show();
+            }
+        }
+    }
     qInfo() << "FullscreenBackground::moveEvent: " << ", old pos: " << event->oldPos() << ", pos: " << event->pos();
     QWidget::moveEvent(event);
 }
