@@ -16,7 +16,7 @@ class UserNameWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit UserNameWidget(bool showDisplayName = true, QWidget *parent = nullptr);
+    explicit UserNameWidget(bool respondFontSizeChange, bool showDisplayName, QWidget *parent = nullptr);
     void initialize();
     void updateUserName(const QString &userName);
     void updateFullName(const QString &displayName);
@@ -31,11 +31,12 @@ private:
     void updateDisplayNameWidget();
 
 private:
-    Dtk::Widget::DLabel *m_userPicLabel;                 // 小人儿图标
-    Dtk::Widget::DLabel *m_fullNameLabel;                // 用户名
+    Dtk::Widget::DLabel *m_userPicLabel;            // 小人儿图标
+    Dtk::Widget::DLabel *m_fullNameLabel;           // 用户名
     Dtk::Widget::DLabel *m_displayNameLabel;        // 用户全名
     bool m_showUserName;                            // 是否显示账户名，记录DConfig的配置
     bool m_showDisplayName;                         // 是否显示全名
     QString m_fullNameStr;                          // 全名
     QString m_userNameStr;                          // 账户名
+    bool m_respondFontSizeChange;                   // 是否响应字体变化
 };
