@@ -124,7 +124,7 @@ void WarningContent::doCancelShutdownInhibit()
     emit m_model->cancelShutdownInhibit(m_model->currentModeState() == SessionBaseModel::ModeStatus::ShutDownMode);
 }
 
-void WarningContent::doAccecpShutdownInhibit()
+void WarningContent::doAcceptShutdownInhibit()
 {
     if (m_model->isCheckedInhibit()) return;
 
@@ -203,7 +203,7 @@ void WarningContent::beforeInvokeAction(bool needConfirm)
         setCenterContent(m_warningView);
 
         connect(view, &InhibitWarnView::cancelled, this, &WarningContent::doCancelShutdownInhibit);
-        connect(view, &InhibitWarnView::actionInvoked, this, &WarningContent::doAccecpShutdownInhibit);
+        connect(view, &InhibitWarnView::actionInvoked, this, &WarningContent::doAcceptShutdownInhibit);
 
         return;
     }
@@ -233,7 +233,7 @@ void WarningContent::beforeInvokeAction(bool needConfirm)
         setCenterContent(m_warningView);
 
         connect(view, &MultiUsersWarningView::cancelled, this, &WarningContent::doCancelShutdownInhibit);
-        connect(view, &MultiUsersWarningView::actionInvoked, this, &WarningContent::doAccecpShutdownInhibit);
+        connect(view, &MultiUsersWarningView::actionInvoked, this, &WarningContent::doAcceptShutdownInhibit);
 
         return;
     }
@@ -260,12 +260,12 @@ void WarningContent::beforeInvokeAction(bool needConfirm)
         setCenterContent(m_warningView);
 
         connect(view, &InhibitWarnView::cancelled, this, &WarningContent::doCancelShutdownInhibit);
-        connect(view, &InhibitWarnView::actionInvoked, this, &WarningContent::doAccecpShutdownInhibit);
+        connect(view, &InhibitWarnView::actionInvoked, this, &WarningContent::doAcceptShutdownInhibit);
 
         return;
     }
 
-    doAccecpShutdownInhibit();
+    doAcceptShutdownInhibit();
 }
 
 void WarningContent::setPowerAction(const SessionBaseModel::PowerAction action)
