@@ -30,7 +30,7 @@ protected:
     void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
     QList<InhibitWarnView::InhibitorData> listInhibitors(const SessionBaseModel::PowerAction action);
     void doCancelShutdownInhibit();
-    void doAccecpShutdownInhibit();
+    void doAcceptShutdownInhibit();
 
 private:
     SessionBaseModel *m_model;
